==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieDodatek.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.enums.JednostkaMiary;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class SwiadczenieDodatek extends GenericDPSObject {
    /**
     * SWIADCZENIE_DODATEK.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SWIADCZENIE_DODATEK.POBIERANE_SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pobieraneSwiadczenieId;

    /**
     * SWIADCZENIE_DODATEK.KOD_DODATKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kodDodatkuId;

    /**
     * SWIADCZENIE_DODATEK.EKWIWALENT
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal ekwiwalent;

    /**
     * SWIADCZENIE_DODATEK.WARTOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal wartosc;

    /**
     * SWIADCZENIE_DODATEK.JEDNOSTKA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private JednostkaMiary jednostka;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_DODATEK.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SWIADCZENIE_DODATEK.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SWIADCZENIE_DODATEK.POBIERANE_SWIADCZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPobieraneSwiadczenieId() {
        return pobieraneSwiadczenieId;
    }

    /**
     * SWIADCZENIE_DODATEK.POBIERANE_SWIADCZENIE_ID
     *
     * @param pobieraneSwiadczenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPobieraneSwiadczenieId(Long pobieraneSwiadczenieId) {
        this.pobieraneSwiadczenieId = pobieraneSwiadczenieId;
    }

    /**
     * @return SWIADCZENIE_DODATEK.KOD_DODATKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKodDodatkuId() {
        return kodDodatkuId;
    }

    /**
     * SWIADCZENIE_DODATEK.KOD_DODATKU_ID
     *
     * @param kodDodatkuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodDodatkuId(Long kodDodatkuId) {
        this.kodDodatkuId = kodDodatkuId;
    }

    /**
     * @return SWIADCZENIE_DODATEK.EKWIWALENT
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getEkwiwalent() {
        return ekwiwalent;
    }

    /**
     * SWIADCZENIE_DODATEK.EKWIWALENT
     *
     * @param ekwiwalent
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEkwiwalent(BigDecimal ekwiwalent) {
        this.ekwiwalent = ekwiwalent;
    }

    /**
     * @return SWIADCZENIE_DODATEK.WARTOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getWartosc() {
        return wartosc;
    }

    /**
     * SWIADCZENIE_DODATEK.WARTOSC
     *
     * @param wartosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartosc(BigDecimal wartosc) {
        this.wartosc = wartosc;
    }

    /**
     * @return SWIADCZENIE_DODATEK.JEDNOSTKA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public JednostkaMiary getJednostka() {
        return jednostka;
    }

    /**
     * SWIADCZENIE_DODATEK.JEDNOSTKA
     *
     * @param jednostka
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setJednostka(JednostkaMiary jednostka) {
        this.jednostka = jednostka;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieDodatek other = (SwiadczenieDodatek) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPobieraneSwiadczenieId() == null ? other.getPobieraneSwiadczenieId() == null : this.getPobieraneSwiadczenieId().equals(other.getPobieraneSwiadczenieId()))
            && (this.getKodDodatkuId() == null ? other.getKodDodatkuId() == null : this.getKodDodatkuId().equals(other.getKodDodatkuId()))
            && (this.getEkwiwalent() == null ? other.getEkwiwalent() == null : this.getEkwiwalent().equals(other.getEkwiwalent()))
            && (this.getWartosc() == null ? other.getWartosc() == null : this.getWartosc().equals(other.getWartosc()))
            && (this.getJednostka() == null ? other.getJednostka() == null : this.getJednostka().equals(other.getJednostka()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPobieraneSwiadczenieId() == null) ? 0 : getPobieraneSwiadczenieId().hashCode());
        result = prime * result + ((getKodDodatkuId() == null) ? 0 : getKodDodatkuId().hashCode());
        result = prime * result + ((getEkwiwalent() == null) ? 0 : getEkwiwalent().hashCode());
        result = prime * result + ((getWartosc() == null) ? 0 : getWartosc().hashCode());
        result = prime * result + ((getJednostka() == null) ? 0 : getJednostka().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", pobieraneSwiadczenieId=").append(pobieraneSwiadczenieId);
        sb.append(", kodDodatkuId=").append(kodDodatkuId);
        sb.append(", ekwiwalent=").append(ekwiwalent);
        sb.append(", wartosc=").append(wartosc);
        sb.append(", jednostka=").append(jednostka);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SwiadczenieDodatek.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.enums.JednostkaMiary;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class SwiadczenieDodatek extends GenericDPSObject {
    /**
     * SWIADCZENIE_DODATEK.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SWIADCZENIE_DODATEK.POBIERANE_SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pobieraneSwiadczenieId;

    /**
     * SWIADCZENIE_DODATEK.KOD_DODATKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kodDodatkuId;

    /**
     * SWIADCZENIE_DODATEK.EKWIWALENT
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal ekwiwalent;

    /**
     * SWIADCZENIE_DODATEK.WARTOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal wartosc;

    /**
     * SWIADCZENIE_DODATEK.JEDNOSTKA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private JednostkaMiary jednostka;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE_DODATEK.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SWIADCZENIE_DODATEK.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SWIADCZENIE_DODATEK.POBIERANE_SWIADCZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPobieraneSwiadczenieId() {
        return pobieraneSwiadczenieId;
    }

    /**
     * SWIADCZENIE_DODATEK.POBIERANE_SWIADCZENIE_ID
     *
     * @param pobieraneSwiadczenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPobieraneSwiadczenieId(Long pobieraneSwiadczenieId) {
        this.pobieraneSwiadczenieId = pobieraneSwiadczenieId;
    }

    /**
     * @return SWIADCZENIE_DODATEK.KOD_DODATKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKodDodatkuId() {
        return kodDodatkuId;
    }

    /**
     * SWIADCZENIE_DODATEK.KOD_DODATKU_ID
     *
     * @param kodDodatkuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodDodatkuId(Long kodDodatkuId) {
        this.kodDodatkuId = kodDodatkuId;
    }

    /**
     * @return SWIADCZENIE_DODATEK.EKWIWALENT
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getEkwiwalent() {
        return ekwiwalent;
    }

    /**
     * SWIADCZENIE_DODATEK.EKWIWALENT
     *
     * @param ekwiwalent
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEkwiwalent(BigDecimal ekwiwalent) {
        this.ekwiwalent = ekwiwalent;
    }

    /**
     * @return SWIADCZENIE_DODATEK.WARTOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getWartosc() {
        return wartosc;
    }

    /**
     * SWIADCZENIE_DODATEK.WARTOSC
     *
     * @param wartosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartosc(BigDecimal wartosc) {
        this.wartosc = wartosc;
    }

    /**
     * @return SWIADCZENIE_DODATEK.JEDNOSTKA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public JednostkaMiary getJednostka() {
        return jednostka;
    }

    /**
     * SWIADCZENIE_DODATEK.JEDNOSTKA
     *
     * @param jednostka
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setJednostka(JednostkaMiary jednostka) {
        this.jednostka = jednostka;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SwiadczenieDodatek other = (SwiadczenieDodatek) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPobieraneSwiadczenieId() == null ? other.getPobieraneSwiadczenieId() == null : this.getPobieraneSwiadczenieId().equals(other.getPobieraneSwiadczenieId()))
            && (this.getKodDodatkuId() == null ? other.getKodDodatkuId() == null : this.getKodDodatkuId().equals(other.getKodDodatkuId()))
            && (this.getEkwiwalent() == null ? other.getEkwiwalent() == null : this.getEkwiwalent().equals(other.getEkwiwalent()))
            && (this.getWartosc() == null ? other.getWartosc() == null : this.getWartosc().equals(other.getWartosc()))
            && (this.getJednostka() == null ? other.getJednostka() == null : this.getJednostka().equals(other.getJednostka()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPobieraneSwiadczenieId() == null) ? 0 : getPobieraneSwiadczenieId().hashCode());
        result = prime * result + ((getKodDodatkuId() == null) ? 0 : getKodDodatkuId().hashCode());
        result = prime * result + ((getEkwiwalent() == null) ? 0 : getEkwiwalent().hashCode());
        result = prime * result + ((getWartosc() == null) ? 0 : getWartosc().hashCode());
        result = prime * result + ((getJednostka() == null) ? 0 : getJednostka().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", pobieraneSwiadczenieId=").append(pobieraneSwiadczenieId);
        sb.append(", kodDodatkuId=").append(kodDodatkuId);
        sb.append(", ekwiwalent=").append(ekwiwalent);
        sb.append(", wartosc=").append(wartosc);
        sb.append(", jednostka=").append(jednostka);
        sb.append("]");
        return sb.toString();
    }
}
